# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/release.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$prodvana/common_config/release.proto\x12\x16prodvana.common_config\"\x87\x02\n\x0fReleaseSettings\x12O\n\x0f\x62ypass_settings\x18\x01 \x01(\x0b\x32\x36.prodvana.common_config.ReleaseSettings.BypassSettings\x1a\xa2\x01\n\x0e\x42ypassSettings\x12\x1d\n\x15no_bypass_protections\x18\x01 \x01(\x08\x12(\n no_bypass_convergence_extensions\x18\x02 \x01(\x08\x12\x1b\n\x13no_bypass_approvals\x18\x03 \x01(\x08\x12*\n\"no_bypass_release_channel_ordering\x18\x04 \x01(\x08\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.common_config.release_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _globals['_RELEASESETTINGS']._serialized_start=65
  _globals['_RELEASESETTINGS']._serialized_end=328
  _globals['_RELEASESETTINGS_BYPASSSETTINGS']._serialized_start=166
  _globals['_RELEASESETTINGS_BYPASSSETTINGS']._serialized_end=328
# @@protoc_insertion_point(module_scope)
