# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/billing/manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eprodvana/billing/manager.proto\x12\x10prodvana.billing\x1a\x1cgoogle/api/annotations.proto\"Q\n\x0cUsageMetrics\x12\x11\n\tnum_users\x18\x01 \x01(\x03\x12\x14\n\x0cnum_runtimes\x18\x02 \x01(\x03\x12\x18\n\x10num_applications\x18\x03 \x01(\x03\"\x14\n\x12GetUsageMetricsReq\"L\n\x13GetUsageMetricsResp\x12\x35\n\rusage_metrics\x18\x01 \x01(\x0b\x32\x1e.prodvana.billing.UsageMetrics2\x8b\x01\n\x0e\x42illingManager\x12y\n\x0fGetUsageMetrics\x12$.prodvana.billing.GetUsageMetricsReq\x1a%.prodvana.billing.GetUsageMetricsResp\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/billing/usageBLZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/billingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'prodvana.billing.manager_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/billing'
  _BILLINGMANAGER.methods_by_name['GetUsageMetrics']._options = None
  _BILLINGMANAGER.methods_by_name['GetUsageMetrics']._serialized_options = b'\202\323\344\223\002\023\022\021/v1/billing/usage'
  _globals['_USAGEMETRICS']._serialized_start=82
  _globals['_USAGEMETRICS']._serialized_end=163
  _globals['_GETUSAGEMETRICSREQ']._serialized_start=165
  _globals['_GETUSAGEMETRICSREQ']._serialized_end=185
  _globals['_GETUSAGEMETRICSRESP']._serialized_start=187
  _globals['_GETUSAGEMETRICSRESP']._serialized_end=263
  _globals['_BILLINGMANAGER']._serialized_start=266
  _globals['_BILLINGMANAGER']._serialized_end=405
# @@protoc_insertion_point(module_scope)
