"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.billing.manager_pb2

class BillingManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    GetUsageMetrics: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.billing.manager_pb2.GetUsageMetricsReq,
        prodvana.proto.prodvana.billing.manager_pb2.GetUsageMetricsResp,
    ]

class BillingManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetUsageMetrics(
        self,
        request: prodvana.proto.prodvana.billing.manager_pb2.GetUsageMetricsReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.billing.manager_pb2.GetUsageMetricsResp: ...

def add_BillingManagerServicer_to_server(servicer: BillingManagerServicer, server: grpc.Server) -> None: ...
